@@ -22,14 +22,12 @@
 #'   function stops and throws an error. Else, a named logical vector is
 #'   returned, indicating which of the packages are installed, and which not.
 #'
-#' @examples
+#' @examplesIf interactive() || identical(Sys.getenv("IN_PKGDOWN"), "true")
 #' \dontrun{
-#' check_if_installed("inexistent_package")
 #' check_if_installed("insight")
-#' check_if_installed("insight", minimum_version = "99.8.7")
-#'
-#' x <- check_if_installed(c("inexistent", "also_not_here"), stop = FALSE)
-#' x
+#' try(check_if_installed("nonexistent_package"))
+#' try(check_if_installed("insight", minimum_version = "99.8.7"))
+#' try(check_if_installed(c("nonexistent", "also_not_here"), stop = FALSE))
 #' }
 #' @export
 check_if_installed <- function(package,
@@ -57,7 +55,7 @@ check_if_installed <- function(package,
     what_you_can_do <- sprintf(
       "Please install %s by running `install.packages(%s)`.",
       if (length(package) > 1L) "them" else "it",
-      paste(sprintf("`%s`", package), collapse = ", ")
+      toString(sprintf("`%s`", package))
     )
   } else if (!is.null(minimum_version)) {
     needs_update <- utils::packageVersion(package) < package_version(minimum_version)
@@ -80,7 +78,7 @@ check_if_installed <- function(package,
       what_you_can_do <- sprintf(
         "Please update %s by running `install.packages(%s)`.",
         if (length(package) > 1L) "them" else "it",
-        paste(sprintf("`%s`", package), collapse = ", ")
+        toString(sprintf("`%s`", package))
       )
     }
   }
@@ -92,8 +90,8 @@ check_if_installed <- function(package,
     if (prompt) {
       what_you_can_do <- sprintf(
         "\nWould you like to %s %s? [y/n] ",
-        if (grepl("update", what_you_can_do)) "update" else "install",
-        if (grepl("them", what_you_can_do)) "them" else "it"
+        if (grepl("update", what_you_can_do, fixed = TRUE)) "update" else "install",
+        if (grepl("them", what_you_can_do, fixed = TRUE)) "them" else "it"
       )
 
       print_color(format_message(what_is_wrong), "red")
@@ -122,7 +120,7 @@ print.check_if_installed <- function(x, ...) {
     print_color(paste0("- ", names(x)[x], collapse = "\n"), "green")
   }
 
-  if (any(!x)) {
+  if (!all(x)) {
     if (any(x)) {
       cat("\n\n")
     }
