@@ -47,7 +47,7 @@ find_algorithm <- function(x, ...) {
 
 #' @export
 find_algorithm.default <- function(x, ...) {
-  warning(sprintf("Objects of class `%s` are not supported.", class(x)[1]), call. = FALSE)
+  format_warning(sprintf("Objects of class `%s` are not supported.", class(x)[1]))
   NULL
 }
 
@@ -81,6 +81,12 @@ find_algorithm.logistf <- function(x, ...) {
   list("algorithm" = x$method)
 }
 
+#' @export
+find_algorithm.flac <- find_algorithm.logistf
+
+#' @export
+find_algorithm.flic <- find_algorithm.logistf
+
 
 #' @export
 find_algorithm.bigglm <- function(x, ...) {
