@@ -104,7 +104,7 @@ find_formula.list <- function(x, verbose = TRUE, ...) {
   if (object_has_names(x, "gam")) {
     if ("mer" %in% names(x)) {
       f.random <- .fix_gamm4_random_effect(find_formula(x$mer)$random)
-      if (length(f.random) == 1) {
+      if (length(f.random) == 1L) {
         f.random <- f.random[[1]]
       } else if (length(f.random) == 0) {
         f.random <- NULL
@@ -190,7 +190,7 @@ find_formula.gamlss <- function(x, verbose = TRUE, ...) {
         stats::as.formula(paste0("~", f))
       })
 
-      if (length(f.random) == 1) {
+      if (length(f.random) == 1L) {
         f.random <- f.random[[1]]
       } else if (grepl("random\\((.*)\\)", safe_deparse(f.cond))) {
         re <- gsub("(.*)random\\((.*)\\)", "\\2", safe_deparse(f.cond))
@@ -262,23 +262,47 @@ find_formula.gamm <- function(x, verbose = TRUE, ...) {
 
 #' @export
 find_formula.rma <- function(x, verbose = TRUE, ...) {
+  formula.yi <- `attributes<-`(stats::formula(x, type = "yi"), NULL)
+  formula.mods <- `attributes<-`(stats::formula(x, type = "mods"), NULL)
+  formula.scale <- `attributes<-`(.safe(stats::formula(x, type = "scale")), NULL)
+
+  model_call <- get_call(x)
+  if (is.null(formula.yi)) {
+    if (is.null(formula.mods)) {
+      formula.yi <- stats::as.formula(paste(model_call$yi, "~ 1"))
+    } else {
+      formula.mods[3] <- formula.mods[2]
+      formula.mods[[2]] <- model_call$yi
+      formula.yi <- formula.mods
+      # TODO: this code line should be identcal to the three lines above, but maybe safer
+      # formula.yi <- formula.mods <- stats::as.formula(paste(all.vars(model_call$yi), "~", all.vars(formula.mods)))
+    }
+  }
+  f <- compact_list(list(
+    conditional = formula.yi,
+    dispersion = formula.mods
+  ))
+  .find_formula_return(f, verbose = verbose)
+}
+
+# TODO: Check these
+
+#' @export
+find_formula.meta_random <- function(x, verbose = TRUE, ...) {
   NULL
 }
 
 #' @export
-find_formula.metaplus <- find_formula.rma
+find_formula.metaplus <- find_formula.meta_random
 
 #' @export
-find_formula.meta_random <- find_formula.rma
+find_formula.meta_fixed <- find_formula.meta_random
 
 #' @export
-find_formula.meta_fixed <- find_formula.rma
+find_formula.meta_bma <- find_formula.meta_random
 
 #' @export
-find_formula.meta_bma <- find_formula.rma
-
-#' @export
-find_formula.deltaMethod <- find_formula.rma
+find_formula.deltaMethod <- find_formula.meta_random
 
 
 
@@ -350,14 +374,14 @@ find_formula.mjoint <- function(x, verbose = TRUE, ...) {
   s <- summary(x)
 
   f.cond <- s$formLongFixed
-  if (length(s$formLongFixed) == 1) {
+  if (length(s$formLongFixed) == 1L) {
     names(f.cond) <- "conditional"
   } else {
     names(f.cond) <- paste0("conditional", seq_along(f.cond))
   }
 
   f.rand <- s$formLongRandom
-  if (length(s$formLongRandom) == 1) {
+  if (length(s$formLongRandom) == 1L) {
     names(f.rand) <- "random"
   } else {
     names(f.rand) <- paste0("random", seq_along(f.rand))
@@ -432,7 +456,7 @@ find_formula.betareg <- function(x, verbose = TRUE, ...) {
   fs <- safe_deparse(f)
 
   if (grepl("|", fs, fixed = TRUE)) {
-    fs <- trim_ws(unlist(strsplit(fs, "|", fixed = TRUE)))
+    fs <- trim_ws(unlist(strsplit(fs, "|", fixed = TRUE), use.names = FALSE))
     f <- list(
       conditional = stats::as.formula(fs[1]),
       precision = stats::as.formula(paste0("~", fs[2]))
@@ -664,8 +688,8 @@ find_formula.ivreg <- function(x, verbose = TRUE, ...) {
   f <- tryCatch(
     {
       f <- safe_deparse(stats::formula(x))
-      cond <- trim_ws(substr(f, start = 0, stop = regexpr(pattern = "\\|", f) - 1))
-      instr <- trim_ws(substr(f, regexpr(pattern = "\\|", f) + 1, stop = 10000L))
+      cond <- trim_ws(substr(f, start = 0, stop = regexpr("|", f, fixed = TRUE) - 1))
+      instr <- trim_ws(substr(f, regexpr("|", f, fixed = TRUE) + 1, stop = 10000L))
 
       list(
         conditional = stats::as.formula(cond),
@@ -693,7 +717,7 @@ find_formula.plm <- function(x, verbose = TRUE, ...) {
   f <- tryCatch(
     {
       f <- safe_deparse(stats::formula(x))
-      bar_pos <- regexpr(pattern = "\\|", f)
+      bar_pos <- regexpr("|", f, fixed = TRUE)
 
       if (bar_pos == -1) {
         stop_pos <- nchar(f) + 1
@@ -730,23 +754,23 @@ find_formula.pgmm <- find_formula.plm
 #' @export
 find_formula.felm <- function(x, verbose = TRUE, ...) {
   f <- safe_deparse(stats::formula(x))
-  f_parts <- trim_ws(unlist(strsplit(f, "(?<!\\()\\|(?![\\w\\s\\+\\(~]*[\\)])", perl = TRUE)))
+  f_parts <- trim_ws(unlist(strsplit(f, "(?<!\\()\\|(?![\\w\\s\\+\\(~]*[\\)])", perl = TRUE), use.names = FALSE))
 
   f.cond <- f_parts[1]
 
-  if (length(f_parts) > 1) {
+  if (length(f_parts) > 1L) {
     f.rand <- paste0("~", f_parts[2])
   } else {
     f.rand <- NULL
   }
 
-  if (length(f_parts) > 2) {
+  if (length(f_parts) > 2L) {
     f.instr <- paste0("~", f_parts[3])
   } else {
     f.instr <- NULL
   }
 
-  if (length(f_parts) > 3) {
+  if (length(f_parts) > 3L) {
     f.clus <- paste0("~", f_parts[4])
   } else {
     f.clus <- NULL
@@ -766,7 +790,7 @@ find_formula.felm <- function(x, verbose = TRUE, ...) {
 #' @export
 find_formula.mhurdle <- function(x, verbose = TRUE, ...) {
   f <- safe_deparse(stats::formula(x)[[3]])
-  f_parts <- trim_ws(unlist(strsplit(f, "(?<!\\()\\|(?![\\w\\s\\+\\(~]*[\\)])", perl = TRUE)))
+  f_parts <- trim_ws(unlist(strsplit(f, "(?<!\\()\\|(?![\\w\\s\\+\\(~]*[\\)])", perl = TRUE), use.names = FALSE))
 
   f.zi <- paste0("~", f_parts[1])
 
@@ -803,7 +827,7 @@ find_formula.mhurdle <- function(x, verbose = TRUE, ...) {
 #' @export
 find_formula.feglm <- function(x, verbose = TRUE, ...) {
   f <- safe_deparse(stats::formula(x))
-  f_parts <- unlist(strsplit(f, "(?<!\\()\\|(?![\\w\\s\\+\\(~]*[\\)])", perl = TRUE))
+  f_parts <- unlist(strsplit(f, "(?<!\\()\\|(?![\\w\\s\\+\\(~]*[\\)])", perl = TRUE), use.names = FALSE)
 
   f.cond <- trim_ws(f_parts[1])
 
@@ -832,7 +856,7 @@ find_formula.feglm <- function(x, verbose = TRUE, ...) {
 #' @export
 find_formula.fixest <- function(x, verbose = TRUE, ...) {
   f <- safe_deparse(stats::formula(x))
-  f_parts <- unlist(strsplit(f, "(?<!\\()\\|(?![\\w\\s\\+\\(~]*[\\)])", perl = TRUE))
+  f_parts <- unlist(strsplit(f, "(?<!\\()\\|(?![\\w\\s\\+\\(~]*[\\)])", perl = TRUE), use.names = FALSE)
 
   f.cond <- trim_ws(f_parts[1])
 
@@ -857,7 +881,7 @@ find_formula.fixest <- function(x, verbose = TRUE, ...) {
 #' @export
 find_formula.feis <- function(x, verbose = TRUE, ...) {
   f <- safe_deparse(stats::formula(x))
-  f_parts <- unlist(strsplit(f, "(?<!\\()\\|(?![\\w\\s\\+\\(~]*[\\)])", perl = TRUE))
+  f_parts <- unlist(strsplit(f, "(?<!\\()\\|(?![\\w\\s\\+\\(~]*[\\)])", perl = TRUE), use.names = FALSE)
 
   f.cond <- trim_ws(f_parts[1])
   id <- parse(text = safe_deparse(x$call))[[1]]$id
@@ -885,7 +909,7 @@ find_formula.feis <- function(x, verbose = TRUE, ...) {
 #' @export
 find_formula.bife <- function(x, verbose = TRUE, ...) {
   f <- safe_deparse(stats::formula(x))
-  f_parts <- unlist(strsplit(f, "|", fixed = TRUE))
+  f_parts <- unlist(strsplit(f, "|", fixed = TRUE), use.names = FALSE)
 
   f.cond <- trim_ws(f_parts[1])
 
@@ -914,7 +938,7 @@ find_formula.ivprobit <- function(x, verbose = TRUE, ...) {
 #' @export
 find_formula.wbm <- function(x, verbose = TRUE, ...) {
   f <- safe_deparse(stats::formula(x))
-  f_parts <- unlist(strsplit(f, "(?<!\\()\\|(?![\\w\\s\\+\\(~]*[\\)])", perl = TRUE))
+  f_parts <- unlist(strsplit(f, "(?<!\\()\\|(?![\\w\\s\\+\\(~]*[\\)])", perl = TRUE), use.names = FALSE)
 
   f.cond <- trim_ws(f_parts[1])
 
@@ -929,7 +953,7 @@ find_formula.wbm <- function(x, verbose = TRUE, ...) {
     if (grepl("\\((.+)\\|(.+)\\)", f_parts[3])) {
       # we have multiple random effects, which we can better extract
       # via ".findbars()"
-      if (length(gregexpr("\\|", f_parts[3])[[1]]) > 1) {
+      if (length(gregexpr("|", f_parts[3], fixed = TRUE)[[1]]) > 1) {
         f.rand <- .findbars(stats::as.formula(paste("~", f_parts[3])))
       } else {
         f.rand <- gsub("(\\(|\\))", "", f_parts[3])
@@ -1027,10 +1051,21 @@ find_formula.clm2 <- function(x, verbose = TRUE, ...) {
 }
 
 
+#' @export
+find_formula.clm <- function(x, verbose = TRUE, ...) {
+  f <- compact_list(list(
+    conditional = stats::formula(x),
+    scale = x$formulas$scale,
+    nominal = x$formulas$nominal
+  ))
+  .find_formula_return(f, verbose = verbose)
+}
+
+
 #' @export
 find_formula.DirichletRegModel <- function(x, verbose = TRUE, ...) {
   f <- safe_deparse(stats::formula(x))
-  f_parts <- unlist(strsplit(f, "(?<!\\()\\|(?![\\w\\s\\+\\(~]*[\\)])", perl = TRUE))
+  f_parts <- unlist(strsplit(f, "(?<!\\()\\|(?![\\w\\s\\+\\(~]*[\\)])", perl = TRUE), use.names = FALSE)
 
   f.cond <- trim_ws(f_parts[1])
 
@@ -1052,8 +1087,8 @@ find_formula.DirichletRegModel <- function(x, verbose = TRUE, ...) {
     conditional3 = stats::as.formula(f.cond3)
   ))
 
-  if (x$parametrization == "alternative") {
-    if (length(out) == 2) names(out)[2] <- "precision"
+  if (x$parametrization == "alternative" && length(out) == 2L) {
+    names(out)[2] <- "precision"
   }
 
   .find_formula_return(out)
@@ -1069,13 +1104,11 @@ find_formula.glmmTMB <- function(x, verbose = TRUE, ...) {
   f.zi <- stats::formula(x, component = "zi")
   f.disp <- stats::formula(x, component = "disp")
 
-  if (identical(safe_deparse(f.zi), "~0") ||
-    identical(safe_deparse(f.zi), "~1")) {
+  if (identical(safe_deparse(f.zi), "~0") || identical(safe_deparse(f.zi), "~1")) {
     f.zi <- NULL
   }
 
-  if (identical(safe_deparse(f.disp), "~0") ||
-    identical(safe_deparse(f.disp), "~1")) {
+  if (identical(safe_deparse(f.disp), "~0") || identical(safe_deparse(f.disp), "~1")) {
     f.disp <- NULL
   }
 
@@ -1085,7 +1118,7 @@ find_formula.glmmTMB <- function(x, verbose = TRUE, ...) {
     stats::as.formula(paste0("~", f))
   })
 
-  if (length(f.random) == 1) {
+  if (length(f.random) == 1L) {
     f.random <- f.random[[1]]
   }
 
@@ -1097,7 +1130,7 @@ find_formula.glmmTMB <- function(x, verbose = TRUE, ...) {
     stats::as.formula(paste0("~", f))
   })
 
-  if (length(f.zirandom) == 1) {
+  if (length(f.zirandom) == 1L) {
     f.zirandom <- f.zirandom[[1]]
   }
 
@@ -1124,7 +1157,7 @@ find_formula.nlmerMod <- function(x, verbose = TRUE, ...) {
     stats::as.formula(paste0("~", f))
   })
 
-  if (length(f.random) == 1) {
+  if (length(f.random) == 1L) {
     f.random <- f.random[[1]]
   }
 
@@ -1140,6 +1173,17 @@ find_formula.nlmerMod <- function(x, verbose = TRUE, ...) {
 }
 
 
+#' @export
+find_formula.hglm <- function(x, verbose = TRUE, ...) {
+  mc <- get_call(x)
+  f.cond <- mc$fixed
+  f.random <- mc$random
+  f.disp <- mc$disp
+
+  f <- compact_list(list(conditional = f.cond, random = f.random, dispersion = f.disp))
+  .find_formula_return(f, verbose = verbose)
+}
+
 
 #' @export
 find_formula.merMod <- function(x, verbose = TRUE, ...) {
@@ -1149,7 +1193,7 @@ find_formula.merMod <- function(x, verbose = TRUE, ...) {
     stats::as.formula(paste0("~", f))
   })
 
-  if (length(f.random) == 1) {
+  if (length(f.random) == 1L) {
     f.random <- f.random[[1]]
   }
 
@@ -1161,6 +1205,15 @@ find_formula.merMod <- function(x, verbose = TRUE, ...) {
 #' @export
 find_formula.rlmerMod <- find_formula.merMod
 
+#' @export
+find_formula.mmrm <- find_formula.merMod
+
+#' @export
+find_formula.mmrm_fit <- find_formula.merMod
+
+#' @export
+find_formula.mmrm_tmb <- find_formula.merMod
+
 #' @export
 find_formula.cpglmm <- find_formula.merMod
 
@@ -1201,7 +1254,7 @@ find_formula.sem <- function(x, verbose = TRUE, ...) {
     stats::as.formula(paste0("~", f))
   })
 
-  if (length(f.random) == 1) {
+  if (length(f.random) == 1L) {
     f.random <- f.random[[1]]
   }
 
@@ -1215,6 +1268,10 @@ find_formula.sem <- function(x, verbose = TRUE, ...) {
 find_formula.lme <- function(x, verbose = TRUE, ...) {
   fm <- stats::formula(x$terms)
   fmr <- eval(x$call$random)
+  if (!is.null(fmr) && safe_deparse(fmr)[1] == "~1") {
+    check_if_installed("nlme")
+    fmr <- stats::as.formula(paste("~1 |", all.vars(nlme::getGroupsFormula(x))))
+  }
   ## TODO this is an intermediate fix to return the correlation variables from lme-objects
   fcorr <- x$call$correlation
   if (!is.null(fcorr)) {
@@ -1259,7 +1316,7 @@ find_formula.mixor <- function(x, verbose = TRUE, ...) {
   f_rs <- x$call$which.random.slope
 
   if (!is.null(f_rs)) {
-    f_rs <- trim_ws(unlist(strsplit(safe_deparse(x$call$formula[[3]]), "\\+")))[f_rs]
+    f_rs <- trim_ws(unlist(strsplit(safe_deparse(x$call$formula[[3]]), "+", fixed = TRUE), use.names = FALSE))[f_rs]
     fmr <- paste(f_rs, "|", f_id)
   } else {
     fmr <- f_id
@@ -1333,7 +1390,7 @@ find_formula.glmm <- function(x, verbose = TRUE, ...) {
     stats::as.formula(paste0("~1|", av[length(av)]))
   })
 
-  if (length(f.random) == 1) {
+  if (length(f.random) == 1L) {
     f.random <- f.random[[1]]
   }
 
@@ -1382,7 +1439,7 @@ find_formula.stanreg <- function(x, verbose = TRUE, ...) {
       })
     }
 
-    if (length(f.random) == 1) {
+    if (length(f.random) == 1L) {
       f.random <- f.random[[1]]
     }
 
@@ -1455,9 +1512,7 @@ find_formula.BFBayesFactor <- function(x, verbose = TRUE, ...) {
       f.cond <- stats::as.formula(fcond)
     }
   } else if (.classify_BFBayesFactor(x) %in% c("ttest1", "ttest2")) {
-    f.cond <- tryCatch(stats::as.formula(x@numerator[[1]]@identifier$formula),
-      error = function(e) NULL
-    )
+    f.cond <- .safe(stats::as.formula(x@numerator[[1]]@identifier$formula))
     f.random <- NULL
   } else {
     return(NULL)
@@ -1489,7 +1544,7 @@ find_formula.model_fit <- function(x, verbose = TRUE, ...) {
     stats::as.formula(paste0("~", fm))
   })
 
-  if (length(f_random) == 1) {
+  if (length(f_random) == 1L) {
     f_random <- f_random[[1]]
   }
 
@@ -1525,7 +1580,7 @@ find_formula.model_fit <- function(x, verbose = TRUE, ...) {
       stats::as.formula(paste0("~", f))
     })
 
-    if (length(f_zirandom) == 1) {
+    if (length(f_zirandom) == 1L) {
       f_zirandom <- f_zirandom[[1]]
     }
 
@@ -1542,7 +1597,7 @@ find_formula.model_fit <- function(x, verbose = TRUE, ...) {
       stats::as.formula(paste0("~", f))
     })
 
-    if (length(f_sigmarandom) == 1) {
+    if (length(f_sigmarandom) == 1L) {
       f_sigmarandom <- f_sigmarandom[[1]]
     }
 
@@ -1559,7 +1614,7 @@ find_formula.model_fit <- function(x, verbose = TRUE, ...) {
       stats::as.formula(paste0("~", f))
     })
 
-    if (length(f_betarandom) == 1) {
+    if (length(f_betarandom) == 1L) {
       f_betarandom <- f_betarandom[[1]]
     }
 
@@ -1599,7 +1654,7 @@ find_formula.model_fit <- function(x, verbose = TRUE, ...) {
     stats::as.formula(paste0("~", fm))
   })
 
-  if (length(f_random) == 1) {
+  if (length(f_random) == 1L) {
     f_random <- f_random[[1]]
   }
 
@@ -1622,7 +1677,7 @@ find_formula.model_fit <- function(x, verbose = TRUE, ...) {
     return(NULL)
   }
 
-  f <- trim_ws(unlist(strsplit(safe_deparse(f), separator)))
+  f <- trim_ws(unlist(strsplit(safe_deparse(f), separator), use.names = FALSE))
 
   c.form <- stats::as.formula(f[1])
   if (length(f) == 2) {
@@ -1698,10 +1753,10 @@ find_formula.model_fit <- function(x, verbose = TRUE, ...) {
     f <- list(f)
   }
   len <- length(f)
-  keep <- sapply(f, function(i) {
+  keep <- vapply(f, function(i) {
     i <- gsub("(~1| | \\|)", "", deparse(i))
     !any(grepl("(Xr\\.\\d|g\\.\\d)", i) | i %in% c("Xr", "g"))
-  })
+  }, TRUE)
   f <- compact_list(f[keep])
   # exceptions, if random effect is named Xr
   if (!length(f) && len > 1) {
@@ -1786,11 +1841,11 @@ find_formula.model_fit <- function(x, verbose = TRUE, ...) {
 
   pattern <- "[\\s*+:()|^,\\-\\/]" # was: "[\\s\\*\\+:\\-\\|/\\(\\)\\^,]"
 
-  parts <- trim_ws(unlist(strsplit(split = pattern, x = LHS, perl = TRUE)))
-  d_LHS <- unique(gsub("(.*)\\$(.*)", "\\1", parts[grepl("(.*)\\$(.*)", parts)]))
+  parts <- trim_ws(unlist(strsplit(split = pattern, x = LHS, perl = TRUE), use.names = FALSE))
+  d_LHS <- unique(gsub("(.*)\\$(.*)", "\\1", grep("(.*)\\$(.*)", parts, value = TRUE)))
 
-  parts <- trim_ws(unlist(strsplit(split = pattern, x = RHS, perl = TRUE)))
-  d_RHS <- unique(gsub("(.*)\\$(.*)", "\\1", parts[grepl("(.*)\\$(.*)", parts)]))
+  parts <- trim_ws(unlist(strsplit(split = pattern, x = RHS, perl = TRUE), use.names = FALSE))
+  d_RHS <- unique(gsub("(.*)\\$(.*)", "\\1", grep("(.*)\\$(.*)", parts, value = TRUE)))
 
   if (n_unique(c(d_LHS, d_RHS)) > 1) {
     format_error("Multiple data objects present in formula. Specify your model using the `data` argument instead.")
