@@ -92,11 +92,12 @@ find_statistic <- function(x, ...) {
     "elm",
     "feis", "felm",
     "gamlss", "garch", "glmmPQL", "gls", "gmm", "gnls",
-    "HLfit",
+    "HLfit", "hglm",
     "ivreg", "ivFixed", "iv_robust", "ivprobit",
     "lm", "lm_robust", "lm.beta", "lme", "lmerMod", "lmerModLmerTest",
     "lmodel2", "lmRob", "lmrob", "lqm", "lqmm",
-    "maxLik", "mixed", "mhurdle", "mlm", "multinom",
+    "maxLik", "mixed", "mhurdle", "mlm", "multinom", "mmrm", "mmrm_fit",
+    "mmrm_tmb",
     "nlmerMod", "nlrq", "nls",
     "ols", "orcutt",
     "pb1", "pb2", "polr",
@@ -131,7 +132,7 @@ find_statistic <- function(x, ...) {
     "poissonmfx", "poissonirr", "psm", "probitmfx", "pgmm",
     "qr", "QRNLMM", "QRLMM",
     "Rchoice", "riskRegression", "robmixglm", "rma", "rma.mv", "rma.uni", "rrvglm",
-    "Sarlm", "sem", "SemiParBIV", "slm", "survreg", "svy_vglm",
+    "Sarlm", "sem", "SemiParBIV", "slm", "slopes", "survreg", "svy_vglm",
     "test_mediation", "tobit",
     "vglm",
     "wbgee",
@@ -154,6 +155,8 @@ find_statistic <- function(x, ...) {
     "anova.rms",
     "coxph.penal",
     "epi.2by2",
+    "flac",
+    "flic",
     "geeglm",
     "logistf",
     "MANOVA", "mlma",
@@ -188,7 +191,7 @@ find_statistic <- function(x, ...) {
 
   # pattern finding ----------------------------------------------------------
 
-  unclear.mods <- c("plm")
+  unclear.mods <- "plm"
 
   if (inherits(x, "glht")) {
     if (x$df == 0) {
@@ -346,6 +349,10 @@ find_statistic <- function(x, ...) {
   if (info$family %in% c("Student's-t", "t Family", "gaussian", "Gaussian") || grepl("(\\st)$", info$family)) {
     linear_model <- TRUE
   }
-  tweedie_fam <- grepl("tweedie", tolower(info$family), fixed = TRUE) | grepl("tweedie", tolower(info$link_function), fixed = TRUE)
+
+  tweedie_fam <-
+    grepl("tweedie", tolower(info$family), fixed = TRUE) |
+      grepl("tweedie", tolower(info$link_function), fixed = TRUE)
+
   (linear_model && tweedie_fam) || inherits(model, c("bcplm", "cpglm", "cpglmm", "zcpglm"))
 }
