@@ -28,37 +28,14 @@ get_deviance <- function(x, ...) {
 #' @rdname get_deviance
 #' @export
 get_deviance.default <- function(x, verbose = TRUE, ...) {
-  dev <- tryCatch(
-    {
-      stats::deviance(x, ...)
-    },
-    error = function(e) {
-      NULL
-    }
-  )
+  dev <- .safe(stats::deviance(x, ...))
 
   if (is.null(dev)) {
-    dev <- tryCatch(
-      {
-        x$deviance
-      },
-      error = function(e) {
-        NULL
-      }
-    )
+    dev <- .safe(x$deviance)
   }
-
   if (is.null(dev)) {
-    dev <- tryCatch(
-      {
-        sum(get_residuals(x, weighted = TRUE, verbose = verbose)^2, na.rm = TRUE)
-      },
-      error = function(e) {
-        NULL
-      }
-    )
+    dev <- .safe(sum(get_residuals(x, weighted = TRUE, verbose = verbose)^2, na.rm = TRUE))
   }
-
   dev
 }
 
@@ -74,7 +51,7 @@ get_deviance.stanreg <- function(x, verbose = TRUE, ...) {
   } else if (info$is_binomial) {
     w <- get_weights(x, null_as_ones = TRUE, verbose = verbose)
     n <- n_obs(x)
-    y <- get_response(x, verbose = FALSE)
+    y <- get_response(x, as_proportion = TRUE, verbose = FALSE)
     mu <- stats::fitted(x)
 
     dev_resids_fun <- x$family$dev.resids
