@@ -155,11 +155,11 @@ get_df.default <- function(x, type = "residual", verbose = TRUE, ...) {
   }
 
   if (!is.null(dof) && length(dof) > 0 && all(dof == 0) && isTRUE(verbose)) {
-    warning("Model has zero degrees of freedom!", call. = FALSE)
+    format_warning("Model has zero degrees of freedom!")
   }
 
   if (is.null(dof) && isTRUE(verbose)) {
-    warning("Could not extract degrees of freedom.", call. = FALSE)
+    format_warning("Could not extract degrees of freedom.")
   }
 
   dof
@@ -172,6 +172,24 @@ get_df.model_fit <- function(x, type = "residual", verbose = TRUE, ...) {
 }
 
 
+#' @export
+get_df.mmrm <- function(x, type = "residual", verbose = TRUE, ...) {
+  type <- match.arg(tolower(type), choices = c("residual", "model", "normal"))
+  if (type == "model") {
+    .model_df(x)
+  } else {
+    summary_table <- stats::coef(summary(x))
+    unname(summary_table[, "df"])
+  }
+}
+
+#' @export
+get_df.mmrm_fit <- get_df.mmrm
+
+#' @export
+get_df.mmrm_tmb <- get_df.mmrm
+
+
 #' @export
 get_df.emmGrid <- function(x, ...) {
   if (!is.null(x@misc$is_boot) && x@misc$is_boot) {
@@ -187,13 +205,13 @@ get_df.emm_list <- function(x, ...) {
     return(.boot_em_df(x))
   }
   s <- summary(x)
-  unname(unlist(lapply(s, function(i) {
+  unlist(lapply(s, function(i) {
     if (is.null(i$df)) {
       rep(Inf, nrow(i))
     } else {
       i$df
     }
-  })))
+  }), use.names = FALSE)
 }
 
 
