@@ -128,6 +128,11 @@
   x$resid_df_obs
 }
 
+#' @keywords internal
+.degrees_of_freedom_residual.hglm <- function(x, verbose = TRUE, ...) {
+  x$dfReFe
+}
+
 #' @keywords internal
 .degrees_of_freedom_residual.glht <- function(x, verbose = TRUE, ...) {
   x$df
@@ -145,7 +150,7 @@
     {
       s <- suppressWarnings(summary(x, covariance = TRUE))
       cs <- lapply(s, function(i) i$rdf)
-      unique(unlist(cs))
+      unique(unlist(cs, use.names = FALSE))
     },
     error = function(e) {
       NULL
@@ -159,7 +164,7 @@
     {
       s <- suppressWarnings(summary(x, covariance = TRUE))
       cs <- lapply(s, function(i) i$rdf)
-      unique(unlist(cs))
+      unique(unlist(cs, use.names = FALSE))
     },
     error = function(e) {
       NULL
