@@ -55,7 +55,7 @@ get_parameters.DirichletRegModel <- function(x,
 
     params <- data.frame(
       Parameter = p_names,
-      Estimate = unname(unlist(cf)),
+      Estimate = unlist(cf, use.names = FALSE),
       Response = rep(names(n_comp), sapply(n_comp, function(i) i)),
       stringsAsFactors = FALSE,
       row.names = NULL
@@ -169,7 +169,7 @@ get_parameters.mvord <- function(x,
                                  component = c("all", "conditional", "thresholds", "correlation"),
                                  ...) {
   component <- match.arg(component)
-  junk <- utils::capture.output(s <- summary(x))
+  junk <- utils::capture.output(s <- summary(x)) # nolint
   # intercepts thresholds
   thresholds <- as.data.frame(s$thresholds)
   thresholds$Parameter <- rownames(thresholds)
@@ -305,7 +305,7 @@ get_parameters.marginaleffects <- function(x, summary = FALSE, merge_parameters
     excl <- c(
       "rowid", "type", "std.error", "contrast", "term", "dydx",
       "statistic", "p.value", "conf.low", "conf.high", "predicted_hi",
-      "predicted_lo", "eps", "marginaleffects_eps"
+      "predicted_lo", "eps", "marginaleffects_eps", "predicted"
     )
     out <- as.data.frame(x[, !names(x) %in% excl, drop = FALSE])
     if ("dydx" %in% colnames(x)) {
