@@ -37,27 +37,35 @@ get_weights <- function(x, ...) {
 }
 
 
+## TODO: probably need own method for nlme, see #727
+
 #' @rdname get_weights
 #' @export
 get_weights.default <- function(x, na_rm = FALSE, null_as_ones = FALSE, ...) {
-  w <- NULL
-  tryCatch(
-    w <- stats::weights(x, ...),
+  weight_vars <- find_weights(x)
+  w <- tryCatch(
+    stats::weights(x, ...),
     error = function(e) NULL,
     warning = function(w) NULL
   )
 
   if (is.null(w)) {
-    tryCatch(
-      w <- stats::model.frame(x)[["(weights)"]],
+    w <- tryCatch(
+      stats::model.frame(x)[["(weights)"]],
       error = function(e) NULL,
       warning = function(w) NULL
     )
   }
 
   if (is.null(w)) {
-    tryCatch(
-      w <- .recover_data_from_environment(x)[[find_weights(x)]],
+    w <- tryCatch(
+      {
+        if (length(weight_vars) > 1) {
+          .recover_data_from_environment(x)[weight_vars]
+        } else {
+          .recover_data_from_environment(x)[[weight_vars]]
+        }
+      },
       error = function(e) NULL,
       warning = function(w) NULL
     )
@@ -70,7 +78,7 @@ get_weights.default <- function(x, na_rm = FALSE, null_as_ones = FALSE, ...) {
 
   # if all weights are 1, set return value to NULL,
   # unless the weights were explicitly set in the model call
-  if (!is.null(w) && all(w == 1L) && is.null(find_weights(x))) {
+  if (!is.null(w) && all(w == 1L) && is.null(weight_vars)) {
     w <- NULL
   }
 
@@ -92,9 +100,9 @@ get_weights.brmsfit <- function(x, na_rm = FALSE, null_as_ones = FALSE, ...) {
 
   if (!is.null(w)) {
     if (length(w) > 1) {
-      return(get_data(x)[w])
+      return(get_data(x, verbose = FALSE)[w])
     } else {
-      w <- get_data(x)[[w]]
+      w <- get_data(x, verbose = FALSE)[[w]]
     }
   }
 
