@@ -72,6 +72,15 @@ link_function.lm <- function(x, ...) {
 #' @export
 link_function.lme <- link_function.lm
 
+#' @export
+link_function.mmrm <- link_function.lm
+
+#' @export
+link_function.mmrm_fit <- link_function.lm
+
+#' @export
+link_function.mmrm_tmb <- link_function.lm
+
 #' @export
 link_function.systemfit <- link_function.lm
 
@@ -197,6 +206,12 @@ link_function.gmnl <- link_function.multinom
 #' @export
 link_function.logistf <- link_function.multinom
 
+#' @export
+link_function.flac <- link_function.multinom
+
+#' @export
+link_function.flic <- link_function.multinom
+
 #' @export
 link_function.lrm <- link_function.multinom
 
@@ -571,13 +586,9 @@ link_function.gamm <- function(x, ...) {
 #' @export
 link_function.bamlss <- function(x, ...) {
   flink <- stats::family(x)$links[1]
-  tryCatch(
-    {
-      stats::make.link(flink)$linkfun
-    },
-    error = function(e) {
-      print_colour("\nCould not find appropriate link-function.\n", "red")
-    }
+  .safe(
+    stats::make.link(flink)$linkfun,
+    print_colour("\nCould not find appropriate link-function.\n", "red")
   )
 }
 
