@@ -56,6 +56,7 @@
 #' * `link_function`: the link-function
 #' * `family`: name of the distributional family of the model. For some exceptions (like some `htest` objects), can also be the name of the test.
 #' * `n_obs`: number of observations
+#' * `n_grouplevels`: for mixed models, returns names and numbers of random effect groups
 #'
 #' @examples
 #' ldose <- rep(0:5, 2)
@@ -89,7 +90,7 @@ model_info <- function(x, ...) {
 
 #' @export
 model_info.data.frame <- function(x, ...) {
-  stop("A data frame is no valid object for this function.", call. = FALSE)
+  format_error("A data frame is no valid object for this function.")
 }
 
 
@@ -101,18 +102,13 @@ model_info.default <- function(x, verbose = TRUE, ...) {
     class(x) <- c(class(x), c("glm", "lm"))
   }
 
-  faminfo <- tryCatch(
-    {
-      if (inherits(x, c("Zelig-relogit"))) {
-        stats::binomial(link = "logit")
-      } else {
-        stats::family(x)
-      }
-    },
-    error = function(x) {
-      NULL
+  faminfo <- .safe({
+    if (inherits(x, "Zelig-relogit")) {
+      stats::binomial(link = "logit")
+    } else {
+      stats::family(x)
     }
-  )
+  })
 
   if (!is.null(faminfo)) {
     .make_family(
@@ -125,7 +121,7 @@ model_info.default <- function(x, verbose = TRUE, ...) {
     )
   } else {
     if (isTRUE(verbose)) {
-      warning("Could not access model information.", call. = FALSE)
+      format_warning("Could not access model information.")
     }
     NULL
   }
@@ -326,6 +322,12 @@ model_info.logistf <- function(x, verbose = TRUE, ...) {
   )
 }
 
+#' @export
+model_info.flac <- model_info.logistf
+
+#' @export
+model_info.flic <- model_info.logistf
+
 #' @export
 model_info.lrm <- model_info.logistf
 
@@ -822,7 +824,7 @@ model_info.summary.lm <- model_info.Arima
 #' @export
 model_info.averaging <- function(x, ...) {
   if (is.null(attributes(x)$modelList)) {
-    warning("Can't calculate covariance matrix. Please use 'fit = TRUE' in 'model.avg()'.", call. = FALSE)
+    format_warning("Can't calculate covariance matrix. Please use 'fit = TRUE' in 'model.avg()'.")
     return(NULL)
   }
   model_info.default(x = attributes(x)$modelList[[1]])
@@ -926,6 +928,21 @@ model_info.BBmm <- model_info.BBreg
 
 
 
+#' @export
+model_info.mmrm <- function(x, ...) {
+  .make_family(
+    x = x,
+    ...
+  )
+}
+
+#' @export
+model_info.mmrm_fit <- model_info.mmrm
+
+#' @export
+model_info.mmrm_tmb <- model_info.mmrm
+
+
 #' @export
 model_info.glmmadmb <- function(x, ...) {
   .make_family(
@@ -1148,6 +1165,28 @@ model_info.polr <- function(x, ...) {
 
 
 
+#' @export
+model_info.hglm <- function(x, ...) {
+  faminfo <- .safe({
+    mc <- get_call(x)$family
+    eval(mc)
+  })
+
+  if (is.null(faminfo)) {
+    return(NULL)
+  }
+
+  .make_family(
+    x = x,
+    fitfam = faminfo$family,
+    logit.link = faminfo$link == "logit",
+    link.fun = faminfo$link,
+    ...
+  )
+}
+
+
+
 #' @export
 model_info.orm <- function(x, ...) {
   faminfo <- stats::binomial(link = "logit")
@@ -1195,15 +1234,10 @@ model_info.gamlss <- function(x, ...) {
 
 #' @export
 model_info.mipo <- function(x, verbose = TRUE, ...) {
-  tryCatch(
-    {
-      models <- eval(x$call$object)
-      model_info(models$analyses[[1]], verbose = verbose, ...)
-    },
-    error = function(e) {
-      NULL
-    }
-  )
+  .safe({
+    models <- eval(x$call$object)
+    model_info(models$analyses[[1]], verbose = verbose, ...)
+  })
 }
 
 
