@@ -129,7 +129,8 @@ n_parameters.MixMod <- function(x,
         flatten = FALSE,
         verbose = FALSE,
         ...
-      )
+      ),
+      use.names = FALSE
     ))
   } else {
     params <- get_parameters(x, effects = effects, component = component, ...)
@@ -201,7 +202,8 @@ n_parameters.brmsfit <- function(x,
       flatten = FALSE,
       verbose = FALSE,
       ...
-    )
+    ),
+    use.names = FALSE
   ))
 }
 
@@ -222,7 +224,8 @@ n_parameters.stanreg <- function(x,
       flatten = FALSE,
       verbose = FALSE,
       ...
-    )
+    ),
+    use.names = FALSE
   ))
 }
 
@@ -242,8 +245,7 @@ n_parameters.gls <- function(x, ...) {
 #' @export
 n_parameters.logitr <- function(x, effects = c("all", "fixed", "random"), ...) {
   effects <- match.arg(effects)
-  switch(
-    effects,
+  switch(effects,
     "fixed" = x$n$parsFixed,
     "random" = x$n$parsRandom,
     x$n$parsFixed + x$n$parsRandom
@@ -279,7 +281,8 @@ n_parameters.bayesx <- function(x, ...) {
       flatten = FALSE,
       verbose = FALSE,
       ...
-    )
+    ),
+    use.names = FALSE
   ))
 }
 
@@ -298,7 +301,8 @@ n_parameters.bayesx <- function(x, ...) {
         flatten = FALSE,
         verbose = FALSE,
         ...
-      )
+      ),
+      use.names = FALSE
     ))
   }
 }
@@ -313,7 +317,8 @@ n_parameters.bayesx <- function(x, ...) {
         flatten = FALSE,
         verbose = FALSE,
         ...
-      )
+      ),
+      use.names = FALSE
     ))
   } else {
     params <- get_parameters(x, effects = effects, ...)
