@@ -132,10 +132,15 @@ print_parameters <- function(x,
   obj <- Reduce(
     function(x, y) {
       # check for valid column name
-      if (parameter_column != "Parameter" && parameter_column %in% colnames(y) && !"Parameter" %in% colnames(y)) {
+      if (parameter_column != "Parameter" &&
+        parameter_column %in% colnames(y) &&
+        !"Parameter" %in% colnames(y)) {
         colnames(y)[colnames(y) == parameter_column] <- "Parameter"
       }
-      merge_by <- unique(c("Parameter", intersect(colnames(y), intersect(c("Effects", "Component", "Group", "Response"), colnames(x)))))
+      merge_by <- unique(c(
+        "Parameter",
+        intersect(colnames(y), intersect(c("Effects", "Component", "Group", "Response"), colnames(x)))
+      ))
       merge(x, y, all.x = FALSE, by = merge_by, sort = FALSE)
     },
     c(list(cp), obj)
@@ -156,7 +161,7 @@ print_parameters <- function(x,
   # split into groups, remove empty elements
   out <- split(obj, f)
   out <- compact_list(lapply(out, function(i) {
-    if (nrow(i) > 0) i
+    if (nrow(i) > 0L) i
   }))
 
   # remove trailing dots
@@ -178,7 +183,7 @@ print_parameters <- function(x,
     parts <- unlist(strsplit(i, ".", fixed = TRUE))
 
     # iterate all parts of the component names, to create title attribute
-    for (j in 1:length(parts)) {
+    for (j in seq_along(parts)) {
       # Rename "fixed", "random" etc. into proper titles. Here we have the
       # "Main title" of a subcomponent (like "Random effects")
       if (parts[j] %in% c("fixed", "random") || (has_zeroinf && parts[j] %in% c("conditional", "zero_inflated"))) {
@@ -267,13 +272,13 @@ print_parameters <- function(x,
 
   # override titles?
   if (!is.null(titles) && length(titles) <= length(out)) {
-    for (i in 1:length(titles)) {
+    for (i in seq_along(titles)) {
       attr(out[[i]], "table_caption") <- c(titles[i], "blue")
     }
   }
 
   if (!is.null(subtitles) && length(subtitles) <= length(out)) {
-    for (i in 1:length(subtitles)) {
+    for (i in seq_along(subtitles)) {
       attr(out[[i]], "table_subtitle") <- c(subtitles[i], "blue")
     }
   }
