@@ -1,4 +1,4 @@
-if (require("testthat") && require("insight") && require("lme4")) {
+if (skip_if_not_or_load_if_installed("lme4")) {
   data(mtcars)
   data(sleepstudy)
 
@@ -10,7 +10,8 @@ if (require("testthat") && require("insight") && require("lme4")) {
   test_that("all_models_equal", {
     expect_true(all_models_equal(m1, m2))
     expect_false(all_models_equal(m1, m2, mtcars))
-    expect_message(expect_false(all_models_equal(m1, m2, mtcars, verbose = TRUE)))
+    suppressMessages(expect_message(all_models_equal(m1, m2, mtcars, verbose = TRUE)))
+    expect_false(suppressMessages(all_models_equal(m1, m2, mtcars, verbose = TRUE)))
     expect_false(all_models_equal(m1, m2, m3))
     expect_message(expect_false(all_models_equal(m1, m4, m2, m3, verbose = TRUE)))
 
