@@ -1,6 +1,6 @@
-if (requiet("testthat") &&
-  requiet("insight") &&
-  requiet("betareg")) {
+if (
+
+  skip_if_not_or_load_if_installed("betareg")) {
   data("GasolineYield")
   data("FoodExpenditure")
 
@@ -35,7 +35,7 @@ if (requiet("testthat") &&
   })
 
   test_that("link_inverse", {
-    expect_identical(link_inverse(m1)(.2), plogis(.2))
+    expect_identical(link_inverse(m1)(0.2), plogis(0.2))
   })
 
   test_that("get_data", {
@@ -44,7 +44,7 @@ if (requiet("testthat") &&
     expect_equal(nrow(get_data(m2)), 38)
     expect_equal(
       colnames(get_data(m2)),
-      c("I(food/income)", "income", "persons", "food", "income.1")
+      c("food", "income", "persons")
     )
   })
 
@@ -96,7 +96,19 @@ if (requiet("testthat") &&
     expect_equal(
       find_parameters(m1),
       list(
-        conditional = c("(Intercept)", "batch1", "batch2", "batch3", "batch4", "batch5", "batch6", "batch7", "batch8", "batch9", "temp"),
+        conditional = c(
+          "(Intercept)",
+          "batch1",
+          "batch2",
+          "batch3",
+          "batch4",
+          "batch5",
+          "batch6",
+          "batch7",
+          "batch8",
+          "batch9",
+          "temp"
+        ),
         precision = "(phi)"
       )
     )
