@@ -1,9 +1,10 @@
 skip_if_not_installed("bife")
-requiet("bife")
+skip_if_not_or_load_if_installed("bife")
+
+dataset <- bife::psid
+mod <- bife(LFP ~ AGE + I(INCH / 1000) + KID1 + KID2 + KID3 | ID, data = dataset)
 
 test_that("get_predicted", {
-  dataset <- bife::psid
-  mod <- bife(LFP ~ AGE + I(INCH / 1000) + KID1 + KID2 + KID3 | ID, data = dataset)
   # link
   x <- get_predicted(mod, predict = "link", data = dataset)
   y <- get_predicted(mod, predict = NULL, type = "link", data = dataset)
@@ -17,3 +18,9 @@ test_that("get_predicted", {
   expect_equal(x, y)
   expect_equal(as.vector(x), z)
 })
+
+
+test_that("get_varcov", {
+  out <- get_varcov(mod)
+  expect_equal(colnames(out), names(coef(mod)))
+})
