@@ -12,7 +12,7 @@ osx <- tryCatch(
   }
 )
 
-if (!osx && requiet("mgcv") && requiet("gamm4") && requiet("rstanarm")) {
+if (!osx && skip_if_not_or_load_if_installed("mgcv") && skip_if_not_or_load_if_installed("gamm4") && skip_if_not_or_load_if_installed("rstanarm")) {
   data <- iris
   data$g <- data$Species
   data$Xr <- data$Species
