@@ -12,7 +12,7 @@ osx <- tryCatch(
   }
 )
 
-if (requiet("mgcv") && requiet("gamm4") && requiet("rstanarm") && !osx) {
+if (skip_if_not_or_load_if_installed("mgcv") && skip_if_not_or_load_if_installed("gamm4") && skip_if_not_or_load_if_installed("rstanarm") && !osx) {
   set.seed(2) ## simulate some data...
   void <- capture.output(
     dat <- mgcv::gamSim(1, n = 400, dist = "normal", scale = 2)
