@@ -16,7 +16,7 @@ unloadNamespace("gam")
 
 .runThisTest <- Sys.getenv("RunAllinsightTests") == "yes"
 
-if (.runThisTest && !osx && requiet("gamm4")) {
+if (.runThisTest && !osx && skip_if_not_or_load_if_installed("gamm4")) {
   set.seed(0)
   void <- capture.output(dat <- gamSim(1, n = 400, scale = 2)) ## simulate 4 term additive truth
   dat$fac <- fac <- as.factor(sample(1:20, 400, replace = TRUE))
