@@ -1,4 +1,4 @@
-if (requiet("lme4")) {
+if (skip_if_not_or_load_if_installed("lme4")) {
   data(mtcars)
   m1 <- lmer(mpg ~ am + (1 | cyl), data = mtcars)
   m2 <- lm(mpg ~ am, data = mtcars)
@@ -27,3 +27,17 @@ if (requiet("lme4")) {
     )
   })
 }
+
+if (skip_if_not_or_load_if_installed("nlme")) {
+  data("Orthodont", package = "nlme")
+  m <- lme( # a model of variance only
+    distance ~ 1,
+    data = Orthodont, # grand mean
+    weights = varConstPower(form = ~ age | Sex)
+  )
+
+  out <- get_weights(m)
+  test_that("get_weights nlme", {
+    expect_identical(colnames(out), c("age", "Sex"))
+  })
+}
