@@ -1,4 +1,4 @@
-if (requiet("robustbase")) {
+if (skip_if_not_or_load_if_installed("robustbase")) {
   data(carrots)
 
   m1 <- glmrob(
