@@ -1,8 +1,8 @@
 testthat::skip_on_covr()
 
-if (requiet("testthat") &&
-  requiet("insight") &&
-  requiet("logistf")) {
+if (
+
+  skip_if_not_or_load_if_installed("logistf")) {
   data(sex2)
   m1 <- logistf(case ~ age + oc + vic + vicl + vis + dia, data = sex2)
 
@@ -47,7 +47,7 @@ if (requiet("testthat") &&
   })
 
   test_that("link_inverse", {
-    expect_equal(link_inverse(m1)(.2), plogis(.2), tolerance = 1e-5)
+    expect_equal(link_inverse(m1)(0.2), plogis(0.2), tolerance = 1e-5)
   })
 
   test_that("get_data", {
