@@ -1,11 +1,12 @@
-requiet("logitr")
+skip_if_not_or_load_if_installed("logitr")
 skip_if_not_installed("logitr", minimum_version = "0.8.0")
 
 mod <- suppressMessages(logitr::logitr(
   data    = yogurt,
   outcome = "choice",
   obsID   = "obsID",
-  pars    = c("price", "feat", "brand")))
+  pars    = c("price", "feat", "brand")
+))
 
 test_that("minimalist tests", {
   d <- get_data(mod)
