@@ -1,12 +1,10 @@
 .runThisTest <- Sys.getenv("RunAllinsightTests") == "yes"
 
-## TODO enable once it's clear what the problem is...
+skip_if_not_or_load_if_installed("lme4")
+skip_if_not_or_load_if_installed("afex")
 
-if (requiet("testthat") &&
-  requiet("insight") &&
-  requiet("lme4") &&
-  suppressPackageStartupMessages(requiet("afex")) &&
-  FALSE) {
+# TODO: check why this is failing
+if (FALSE) {
   data(sleepstudy)
 
   set.seed(123)
@@ -102,8 +100,8 @@ if (requiet("testthat") &&
   })
 
   test_that("link_inverse", {
-    expect_identical(link_inverse(m1)(.2), .2)
-    expect_identical(link_inverse(m2)(.2), .2)
+    expect_identical(link_inverse(m1)(0.2), 0.2)
+    expect_identical(link_inverse(m2)(0.2), 0.2)
   })
 
   test_that("get_data", {
