@@ -1,4 +1,4 @@
-if (require("testthat") && require("insight") && require("lme4")) {
+if (skip_if_not_or_load_if_installed("lme4")) {
   set.seed(123)
   startvec <- c(Asym = 200, xmid = 725, scal = 350)
   nm1 <-
@@ -9,6 +9,7 @@ if (require("testthat") && require("insight") && require("lme4")) {
     )
 
   test_that("model_info", {
+    skip_if(getRversion() < "4.1.0")
     expect_true(model_info(nm1)$is_linear)
   })
 
